==> errai-codegen-2.0.1.Final-redhat-1.jar: org/jboss/errai/codegen/literal/ClassLiteral.java <==
/*
 * Copyright 2011 JBoss, by Red Hat, Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.errai.codegen.literal;

import static org.jboss.errai.codegen.builder.callstack.LoadClassReference.getClassReference;

import org.jboss.errai.codegen.Context;
import org.jboss.errai.codegen.meta.MetaClass;
import org.jboss.errai.codegen.meta.MetaClassFactory;

/**
 * @author Mike Brock <cbrock@redhat.com>
 */
public class ClassLiteral extends LiteralValue<Class<?>> implements TypeLiteral {
  
  public ClassLiteral(Class<?> value) {
    super(value);
  }

  @Override
  public String getCanonicalString(Context context) {
    if (context == null) {
      return getValue().getName() + ".class";
    } else {
      return getClassReference(MetaClassFactory.get(getValue()), context) + ".class";
    }
  }
  
  @Override
  public MetaClass getType() {
    return MetaClassFactory.get(Class.class);
  }
  
  public MetaClass getActualType() {
    return super.getType();
  }
}

==> errai-codegen-2.1.0.Final-redhat-1.jar: org/jboss/errai/codegen/literal/ClassLiteral.java <==
/*
 * Copyright 2011 JBoss, by Red Hat, Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.errai.codegen.literal;

import org.jboss.errai.codegen.Context;
import org.jboss.errai.codegen.meta.MetaClass;
import org.jboss.errai.codegen.meta.MetaClassFactory;

import static org.jboss.errai.codegen.builder.callstack.LoadClassReference.getClassReference;

/**
 * @author Mike Brock <cbrock@redhat.com>
 */
public class ClassLiteral extends LiteralValue<Class<?>> implements TypeLiteral {
  
  public ClassLiteral(final Class<?> value) {
    super(value);
  }

  @Override
  public String getCanonicalString(final Context context) {
    if (context == null) {
      return getValue().getName() + ".class";
    } else {
      return getClassReference(MetaClassFactory.get(getValue()), context) + ".class";
    }
  }
  
  @Override
  public MetaClass getType() {
    return MetaClassFactory.get(Class.class);
  }
  
  public MetaClass getActualType() {
    return super.getType();
  }
}
